[Lldb-commits] [lldb] r223432 - Added the LLDB enumeration necessary to find the

Sean Callanan scallanan at apple.com
Thu Dec 4 17:17:47 PST 2014


Author: spyffe
Date: Thu Dec  4 19:17:47 2014
New Revision: 223432

URL: http://llvm.org/viewvc/llvm-project?rev=223432&view=rev
Log:
Added the LLDB enumeration necessary to find the
Clang headers directory.  Needed by r223430.

Modified:
    lldb/trunk/include/lldb/lldb-enumerations.h

Modified: lldb/trunk/include/lldb/lldb-enumerations.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/include/lldb/lldb-enumerations.h?rev=223432&r1=223431&r2=223432&view=diff
==============================================================================
--- lldb/trunk/include/lldb/lldb-enumerations.h (original)
+++ lldb/trunk/include/lldb/lldb-enumerations.h Thu Dec  4 19:17:47 2014
@@ -853,8 +853,8 @@ namespace lldb {
         ePathTypePythonDir,             // Find Python modules (PYTHONPATH) directory
         ePathTypeLLDBSystemPlugins,     // System plug-ins directory
         ePathTypeLLDBUserPlugins,       // User plug-ins directory
-        ePathTypeLLDBTempSystemDir      // The LLDB temp directory for this system that will be cleaned up on exit
-        
+        ePathTypeLLDBTempSystemDir,     // The LLDB temp directory for this system that will be cleaned up on exit
+        ePathTypeClangDir               // Find path to Clang builtin headers
     } PathType;
     
     //----------------------------------------------------------------------





More information about the lldb-commits mailing list